Action class

Triggers a server-side event or a local client-side function.

Constructors

Action({Map<String, dynamic>? event, FunctionCall? functionCall})
Action.fromJson(Map<String, dynamic> json)
factory

Properties

event Map<String, dynamic>?
final
functionCall FunctionCall?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited