ChildListTemplate class

A template for generating a dynamic list of children.

Constructors

ChildListTemplate({required String componentId, required String path})
ChildListTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

componentId String
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited