CreateSurfaceMessage class

Signals the client to create a new surface.

Inheritance

Constructors

CreateSurfaceMessage({String version = 'v0.9', required String surfaceId, required String catalogId, Map<String, dynamic>? theme, bool sendDataModel = false})

Properties

catalogId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendDataModel bool
final
surfaceId String
final
theme Map<String, dynamic>?
final
version String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited