EventNotifier<T> class

A synchronous, typed event emitter for discrete events.

Implemented types

Constructors

EventNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener(T event)) → void
Registers listener to be called whenever an event is emitted.
override
dispose() → void
Removes all listeners.
emit(T event) → void
Emits an event to all registered listeners.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener(T event)) → void
Removes a previously registered listener.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited